summaryrefslogtreecommitdiff
path: root/src/libs/sig/ops_expand.c
diff options
context:
space:
mode:
authorVito Caputo <vcaputo@pengaru.com>2023-05-23 22:24:13 -0700
committerVito Caputo <vcaputo@pengaru.com>2023-05-23 22:24:13 -0700
commitfffa21663da84250469dec2da26062f66a8c171a (patch)
tree7c138088cd09515efc9c3e6050c57ed672af18d3 /src/libs/sig/ops_expand.c
parente72be78e98b166e5b6dcdc7ec7b22d2b4d9ee5ca (diff)
libs/sig: mechanical rename sig_t->sig_sig_t
sig_t collides with some signals-related system header on macos. Just prefix it under the sig namespace.. leaving sig_ops alone for now, but maybe they'll become sig_sig_ops in the future too. Note nothing in master actually uses libs/sig currently, but I have an experimental branch with a dusty module using it.
Diffstat (limited to 'src/libs/sig/ops_expand.c')
-rw-r--r--src/libs/sig/ops_expand.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/libs/sig/ops_expand.c b/src/libs/sig/ops_expand.c
index 76791e4..31602ed 100644
--- a/src/libs/sig/ops_expand.c
+++ b/src/libs/sig/ops_expand.c
@@ -4,7 +4,7 @@
typedef struct ops_expand_ctxt_t {
- sig_t *value;
+ sig_sig_t *value;
} ops_expand_ctxt_t;
@@ -14,7 +14,7 @@ static size_t ops_expand_size(va_list ap)
}
/* expects a single sig_t: value
* input range is assumed to be 0..1, outputs expanded
* range of -1..+1
*/
@@ -24,7 +24,7 @@ static void ops_expand_init(void *context, va_list ap)
assert(ctxt);
- ctxt->value = va_arg(ap, sig_t *);
+ ctxt->value = va_arg(ap, sig_sig_t *);
}
© All Rights Reserved
@@ -14,7 +14,7 @@ static size_t ops_expand_size(va_list ap)
}
-/* expects a single sig_t: value
+/* expects a single sig_sig_t: value
* input range is assumed to be 0..1, outputs expanded
* range of -1..+1